# Royal


## Intro

`royal` is a library and framework for building economic market models. It provides a way to create an artifical market, where you control the items, the customers, and the orders processed for it. It can also provide a model of a stock market, or a currency exchange.

## Purpose

The stock market can often times be unpredictable. It's composed of billions of trades across thousands of securities, stemming from thousands of customers. The data we have on the stock market is limited and difficult to understand without knowing what drives it.

Royal is an artifical trading or stock exchange environment used for research and modeling. It's intended to allow further and closer examination of the behaviors exhibited in trading markets.

## Development Status

Royal is currently in the alpha development phase. 